const columns = require("./columns");
const orderHttps = require("../../../utils/serverOrder");
const validate = require("../../../utils/validate");
import {
  createStoreBindings
} from 'mobx-miniprogram-bindings'
import {
  store
} from "../../../store/index";
Page({
  data: {
    loading: false,
    popupOptions: [],
    popupType: "",
    popupKey: "",
    popupTitle: "",
    popupApi: "",
    show: false,
    config: columns.config,
    formData: {
      ...columns.formData
    },
    popupValue: '',
    show: false,
    background: [
      'https://fastly.jsdelivr.net/npm/@vant/assets/apple-1.jpeg',
      'https://fastly.jsdelivr.net/npm/@vant/assets/apple-2.jpeg',
      'https://fastly.jsdelivr.net/npm/@vant/assets/apple-1.jpeg',
      'https://fastly.jsdelivr.net/npm/@vant/assets/apple-2.jpeg',
    ],
    indicatorDots: true,
    vertical: false,
    autoplay: true,
    interval: 3000,
    duration: 500,
    date: '',
  },

  onLoad() {
    this.storeBindings = createStoreBindings(this, {
      store,
      fields: ["token", "phone"],
      actions: ["setPhone"],
    });
  },
  onUnload() {
    this.storeBindings.destroyStoreBindings();
  },
  async submitTap() {
    const token = this.data.token ?? ""
    if (token === '') {
      wx.navigateTo({
        url: "../login/index"
      })
      return
    }
    const {
      loading,
      formData,
      phone
    } = this.data

    if (loading) return
    this.setData({
      loading: true
    })
    const {
      city,
      act_time,
      act_day_count,
      budget,
      participant,
      require_item,
      req_demand,
    } = formData
    const keyMsg = this.valKey()
    if (keyMsg) {
      this.showToastMsg(keyMsg)
      this.setData({
        loading: false
      })
      return
    }
    const msg = validate.valMobile(phone)
    if (msg) {
      this.showToastMsg(msg)
      this.setData({
        loading: false
      })
      return
    }
    const {
      code,
      data,
      msg: ss
    } = await orderHttps.orderAdd({
      city,
      act_time,
      act_day_count,
      budget,
      participant,
      require_item,
      req_demand: req_demand.toString(),
      phone
    })

    if (code === 1) {
      this.showToastMsg('会务订单创建成功！')
      wx.redirectTo({
        url: '../order-details/index?id=' + data.reqCode
      })
      this.setData({
        formData: {
          ...columns.formData
        }
      })
    } else if (code === 0) {
      this.showToastMsg(ss)
    } else {

    }

    this.setData({
      loading: false
    })
  },
  async orderAdd(model) {


    return {
      code,
      reqCode: data.reqCode,
      msg
    }

  },
  valKey() {
    let msg = ""
    const {
      formData,
      config
    } = this.data
    const list = [
      "city",
      "act_time",
      "budget",
      "participant",
      "require_item",
      "req_demand"
    ]
    list.forEach((key) => {
      if (config[key] === 'checkbox') {
        if (formData[key].length === 0) {
          msg = `至少选择一个${config[key].title}！`
        }
      } else {
        if (!formData[key]) {
          msg = `${config[key].title}不能为空！`
        }
      }
    })
    return msg
  },

  onPhoneChange(event) {
    this.setData({
      phone:event.detail.value
    })
  },
  //输入组件 只读点击选择数据
  onFormChange(event) {
    const token = this.data.token ?? ""
    const key = event.currentTarget.dataset.type
    const type = this.data.config[key].type
    if (token === '' && (type === "city" || type === "radio" || type === 'checkbox')) {
      wx.navigateTo({
        url: "../login/index"
      })
      return
    }
    console.log(key);
    console.log(this.data.formData[key]);
    console.log(this.data.config[key]);
    this.setData({
      popupValue: this.data.formData[key],
      popupType: this.data.config[key].type,
      popupTitle: this.data.config[key].title,
      popupApi: this.data.config[key].api,
      popupKey: key,
      show: true,
      popupOptions: []
    });
  },
  tapItemClick(e) {
    const {
      label,
      popupKey,
      popupType,
      value,
      count
    } = e.detail
    // console.log(e);
    let form = {
      ...this.data.formData
    }
    form[popupKey] = value
    form[popupKey + '_name'] = label
    if (popupType === 'time') {
      form.act_day_count = count
    }
    this.setData({
      show: false,
      formData: form
    });
  },

  popupLeft() {
    this.setData({
      show: false,
    });
  },
  showToastMsg(msg) {
    wx.showToast({
      title: msg,
      icon: 'none',
      duration: 2000
    })
  }
})